#!/usr/bin/env python
#
# ServerStatistics post-processing script for NZBGet
#
# Copyright (C) 2013 Andrey Prygunkov <hugbug@users.sourceforge.net>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#


##############################################################################
### NZBGET POST-PROCESSING SCRIPT                                          ###

# Print server statistics.
#
# This script prints what servers were used for download of nzb-file and
# their success and failure quotas.
#
# NOTE: This script requires Python to be installed on your system.

### NZBGET POST-PROCESSING SCRIPT                                          ###
##############################################################################


import os
import sys

# Exit codes used by NZBGet
POSTPROCESS_SUCCESS=93
POSTPROCESS_NONE=95
POSTPROCESS_ERROR=94

# Check if the script is called from nzbget 12.0 or later
if not 'NZBPP_HEALTHDELETED' in os.environ:
	print('*** NZBGet post-processing script ***')
	print('This script is supposed to be called from nzbget (12.0 or later).')
	sys.exit(POSTPROCESS_ERROR)

# Reading server configuration from nzbget.conf
servers = []
minlevel = 0
id = 1
while True:
	serv = {}
	serv['id'] = id
	serv['name'] = os.environ.get('NZBOP_SERVER%i_NAME' % id, '')
	serv['host'] = os.environ.get('NZBOP_SERVER%i_HOST' % id, '')
	serv['port'] = int(os.environ.get('NZBOP_SERVER%i_PORT' % id, '119'))
	port = os.environ.get('NZBOP_SERVER%i_PORT' % id, '')
	serv['level'] = int(os.environ.get('NZBOP_SERVER%i_LEVEL' % id, '0'))

	if (serv['name'] == '' and serv['host'] == '' and port == ''):
		break;

	if serv['name'] == '':
		serv['name'] = 'server%i' % id
	
	if id == 1:
		minlevel = serv['level']

	if serv['level'] < minlevel:
		minlevel = serv['level']
	
	servers.append(serv)
	id += 1

# Total statistics
all_total_articles = int(os.environ.get('NZBPP_TOTALARTICLES', '0'))
all_success_articles = int(os.environ.get('NZBPP_SUCCESSARTICLES', '0'))
all_failed_articles = int(os.environ.get('NZBPP_FAILEDARTICLES', '0'))
print('Articles: %i total (incl. pars), %i success, %i failed' % (all_total_articles, all_success_articles, all_failed_articles))

# Server statistics
for serv in servers:
	success_articles = int(os.environ.get('NZBPP_SERVER%i_SUCCESSARTICLES' % serv['id'], '0'))
	failed_articles = int(os.environ.get('NZBPP_SERVER%i_FAILEDARTICLES' % serv['id'], '0'))
	if success_articles > 0 or failed_articles > 0:
		serv_type = '[main-server]' if serv['level'] == minlevel else '[fill-server]'
		serv_title = '%s (%s:%i)' % (serv['name'], serv['host'], serv['port'])
		all_quota = (success_articles + failed_articles) * 100.0 / (all_success_articles + all_failed_articles)
		success_quota = success_articles * 100.0 / (success_articles + failed_articles)
		failure_quota = failed_articles * 100.0 / (success_articles + failed_articles)
		print('%s %s: %0.1f%% articles, %0.1f%% success, %0.1f%% failures' % (serv_type, serv_title, all_quota, success_quota, failure_quota))


sys.exit(POSTPROCESS_SUCCESS)
